==> huaweicloudsdkmoderation-3.0.55-py2.py3-none-any.whl: huaweicloudsdkmoderation/v2/model/run_check_task_jobs_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunCheckTaskJobsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'result': 'list[CheckTaskJobsItemsBody]'
    }

    attribute_map = {
        'result': 'result'
    }

    def __init__(self, result=None):
        """RunCheckTaskJobsResponse - a model defined in huaweicloud sdk"""
        
        super(RunCheckTaskJobsResponse, self).__init__()

        self._result = None
        self.discriminator = None

        if result is not None:
            self.result = result

    @property
    def result(self):
        """Gets the result of this RunCheckTaskJobsResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :return: The result of this RunCheckTaskJobsResponse.
        :rtype: list[CheckTaskJobsItemsBody]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this RunCheckTaskJobsResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :param result: The result of this RunCheckTaskJobsResponse.
        :type: list[CheckTaskJobsItemsBody]
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunCheckTaskJobsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmoderation-3.0.58-py2.py3-none-any.whl: huaweicloudsdkmoderation/v2/model/run_check_task_jobs_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunCheckTaskJobsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'result': 'list[CheckTaskJobsItemsBody]',
        'count': 'int'
    }

    attribute_map = {
        'result': 'result',
        'count': 'count'
    }

    def __init__(self, result=None, count=None):
        """RunCheckTaskJobsResponse - a model defined in huaweicloud sdk"""
        
        super(RunCheckTaskJobsResponse, self).__init__()

        self._result = None
        self._count = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if count is not None:
            self.count = count

    @property
    def result(self):
        """Gets the result of this RunCheckTaskJobsResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :return: The result of this RunCheckTaskJobsResponse.
        :rtype: list[CheckTaskJobsItemsBody]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this RunCheckTaskJobsResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :param result: The result of this RunCheckTaskJobsResponse.
        :type: list[CheckTaskJobsItemsBody]
        """
        self._result = result

    @property
    def count(self):
        """Gets the count of this RunCheckTaskJobsResponse.

        符合查询条件的总任务数量。 

        :return: The count of this RunCheckTaskJobsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this RunCheckTaskJobsResponse.

        符合查询条件的总任务数量。 

        :param count: The count of this RunCheckTaskJobsResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunCheckTaskJobsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
